import {ReactElement} from "react";
import {domToReact, Element} from "html-react-parser";
import {nunito_sans, raleway} from "@/app/fonts";
import {Code} from "bright";
import {mark} from "@/bright-extension/mark";

export type nodeHandlerResult = {match :boolean, element? :ReactElement}
export type nodeHandler = (node :Element) => nodeHandlerResult

function h1(node: Element): nodeHandlerResult {
    if (node.name === "h1") {
        if (node.attribs.class === "title") {
            return {
                match: true,
                element: (
                    <h1 className={`${raleway.className} mx-auto w-224 text-4xl`}>
                        {domToReact(node.children)}
                    </h1>
                ),
            };
        }
        return {
            match: true,
            element: (
                <h1 className={`${raleway.className} mx-auto w-224 text-3xl`}>
                    {domToReact(node.children)}
                </h1>
            ),
        };
    }

    return { match: false};
}

function h2(node: Element): nodeHandlerResult {
    if (node.name === "h2") {
        return {
          match: true,
          element: (
              <h1 className={`${raleway.className} mx-auto w-224 text-2xl`}>
                  {domToReact(node.children)}
              </h1>
          )
        };
    }

    return {match: false};
}

function h3(node: Element): nodeHandlerResult {
    if (node.name === "h3") {
        return {
            match: true,
            element: (
                <h1 className={`${raleway.className} mx-auto w-224 text-xl`}>
                    {domToReact(node.children)}
                </h1>
            )
        };
    }
    return {match: false};
}

function code(node: Element): nodeHandlerResult {
    if (node.name === "code") {
        let linenumber = false;
        if ("class" in node.attribs) {
            const classes = node.attribs.class.split(" ");
            if (classes.includes("linenumber")) {
                linenumber = true;
            }
        }

        return {
            match: true,
            element: (
                <div className={`w-224 mx-auto`}>
                    <Code
                        lang={`${node.attribs.lang}`}
                        lineNumbers={linenumber}
                        extensions={[mark]}
                    >
                        {domToReact(node.children)}
                    </Code>
                </div>
            )
        };
    }

    return {match: false};
}

function p(node: Element): nodeHandlerResult {
    if (node.name === "p") {
        if (node.attribs.class === "paragraph") {
            return {
                match: true,
                element: (
                    <h1 className={`${nunito_sans.className} mx-auto w-224`}>
                        {domToReact(node.children)}
                    </h1>
                )
            };
        }
    }
    return {match: false};
}

export const handlers: nodeHandler[] = [h1, h2, h3, code, p];